@@ -1,6 +1,10 @@
 PythonSum = sum
 import numpy as np
-from numpy import where, logical_and, isscalar, all, any
+from numpy import logical_and, isscalar, any#, where
+
+# for PyPy
+from FDmisc import where
+
 from boundsurf import surf, boundsurf, mul_fixed_interval, mul_handle_nan
 from operator import gt as Greater, lt as Less
 try:
